<?php

namespace MSDev\MSClientAPI;

use MSDev\MSLib\FMException;
use MSDev\MSLib\FMConnector;
use MSDev\MSClientAPI\Client;

class ClientPost {

	public function CreateClient($env) {
		$this->env 		= $env;

		$rr				= $this->env->get('rr');
		$data			= $this->parseData($rr, $rr->getData()); 
		$client 		= $this->doCreate($data);

		return $rr->respond('Client', $client);
	}
	
	private function parseData($rr, $data) {
		// clean out any data which is not permitted
		$data			= $rr->cleanData($data);
		
		// ensure that we have the required minimum data
		$req			= $this->env->get('RequiredFields');	
		$match			= array_intersect(array_keys($data), $req);
		
		if(count($match) != count($req)) {
			throw new \Exception('Missing required field, must submit at least: '.implode(', ', $req), 400);
		}
		
		// make sure the email address doesn't already exist
		$this->checkForUser($data);
		
		return $data;
	}
	
	private function doCreate($data) {
		try {
			$fm 		= $this->env->get('fm');
			$client		= $fm->insert(
				$this->env->get('UserLayout'),
				$data,
				FMConnector::FM_RECORD
			);
	
			// clear the system IDs
			unset($client[FMConnector::FM_RECORD_ID]);
			unset($client[FMConnector::FM_MOD_ID]);
			
			return $client;
		} catch(FMException $e) {
			$id			= $e->getFMCode() == 401 ? 404 : 500;
			throw new \Exception($e->getFMError(), $id);
		}
	}

	private function checkForUser($data) {
		try {
			$fm			= $this->env->get('fm');
			$client		= $fm->select(
					'Users',
					array(
							'Email' => "=={$data['Email']}",
					)
			);
			throw new \Exception("Client with email address {$data['Email']} already exists with client ID {$client[0]['ID']}", 412);
		} catch(FMException $e) {
			// we actually want an error here - a 401 record not found
			if($e->getFMCode() != 401) {
				throw new \Exception($e->getFMError(), 500);
			}
		}
	}
}