<?php

namespace MSDev\MSRouter;

class Router extends \PHPRouter\Router {
	
	/**
	 * Array that holds all Route objects
	 * @var array
	 */
	private $routes = array();
	
	/**
	 * The base REQUEST_URI. Gets prepended to all route url's.
	 * @var string
	 */
	private $basePath = '';
	
	/**
	 * @param RouteCollection $collection
	 */
	public function __construct(RouteCollection $collection)
	{
		$this->routes = $collection;
	}
	
	/**
	 * Match given request _url and request method and see if a route has been defined for it
	 * If so, return route's target
	 * If called multiple times
	 *
	 * @param string $requestUrl
	 * @param string $requestMethod
	 * @return bool
	 */
	public function match($requestUrl, $requestMethod = 'GET')
	{
		foreach ($this->routes->all() as $routes) {
			// compare server request method with route's allowed http methods
			if (! in_array($requestMethod, (array) $routes->getMethods())) {
				continue;
			}

			// check if request _url matches route regex. if not, return false.
			if (! preg_match("@^".$this->basePath.$routes->getRegex()."*$@i", $requestUrl, $matches)) {
				continue;
			}

			$params = array();
			if (preg_match_all("/:([\w-%]+)/", $routes->getUrl(), $argument_keys)) {
	
				// grab array with matches
				$argument_keys = $argument_keys[1];
	
				// loop trough parameter names, store matching value in $params array
				foreach ($argument_keys as $key => $name) {
					if (isset($matches[$key + 1])) {
						$params[$name] = $matches[$key + 1];
					}
				}
	
			}
	
			$routes->setParameters($params);
	
			return $routes;
		}

		return false;
	}
	
	/**
     * Create routes by array, and return a Router object
     *
     * @param array $config provide by Config::loadFromFile()
     * @return Router
     */
    public static function parseConfig(array $config)
    {
        $collection = new RouteCollection();
        foreach ($config['routes'] as $name => $route) {
            $collection->attachRoute(new Route($route[0], array(
                '_controller' => str_replace('.', '::', $route[1]),
                'methods' => $route[2]
            )));
        }

        $router = new Router($collection);
        if (isset($config['base_path'])) {
            $router->setBasePath($config['base_path']);
        }

        return $router;
    }

}