<?php

session_start();
require_once(__DIR__.DIRECTORY_SEPARATOR.'autoload.php');

use PHPRouter\Config;
use PHPRouter\Router;
use MSDev\MSLib\EnvironmentManager;
use MSDev\MSClientAPI\RequestResponse;

$e						= new EnvironmentManager();
$env					= $e->BuildEnvironment(__DIR__);
$env->set('rr', new RequestResponse($env));

// match a route and process
try {
	$routeConfig 		= Config::loadFromFile(__DIR__.DIRECTORY_SEPARATOR.'app'.DIRECTORY_SEPARATOR.'routes.yaml');
	$router 			= Router::parseConfig($routeConfig);
	$route 				= $router->matchCurrentRequest();
} catch (Exception $e) {
	$env->get('err')->defaultError(500);
	exit();
}

if(!isset($route) || !$route) {
	$env->get('err')->defaultError(404);
	exit();
}

// find out what needs to happen
$action 				= explode('::', $route->getConfig()['_controller']);
try {
    // if they aren't trying to login or out make sure they are logged in
    if(!in_array($action[0], array('MSDev\MSClientAPI\Authentication', 'MSDev\MSClientAPI\RSAEncryption'))) {
        // make sure that the user is logged in
        if(!isset($_SESSION['loggedIn'])) {
            throw new Exception('User not authenticated', 401);
        }
    
        // make sure the session hasn't expired
        if(!isset($_SESSION['lastAccess']) || $_SESSION['lastAccess'] + 600 < time()) {
            throw new Exception('Session expired', 401);
        }
    
        // update the last access
        $_SESSION['lastAccess'] = time();
    }

    $class 				= new $action[0];
    $func 				= $action[1];
	$resp				= $class->$func($env, $route->getParameters());
	print($resp);
} catch(Exception $e) {
	$env->get('err')->customMessage($e->getCode(), $e->getMessage());
}















































function showMe($data, $title=false, $die=false, $location=true) {
	echo '<div class="debug">';
	if($location || $title) {
		echo '  <p>================================================<br/>';
	}
	if($title) {
		echo    $title;
	}
	if($title && $location) {
		echo '<br/>================================================</br/>';
	}
	if($location) {
		$caller = debug_backtrace();
		echo $caller[0]['file'].' # '.$caller[0]['line'];
	}
	if($title || $location) {
		echo '<br/>================================================</p>';
	}

	if(is_array($data) || is_object($data)) {
		echo '<pre>';
		print_r($data);
		echo '</pre>';
	} else {
		echo '<p>'.$data.'</p>';
	}
	echo '</div>';
	if($die == true) {
		die();
	}
}